@@ -69,7 +69,7 @@ NMVariantMapMap SecretAgent::GetSecrets(const NMVariantMapMap &connection, const
     qCDebug(PLASMA_NM) << "Flags:" << flags;
 
     const QString callId = connection_path.path() % setting_name;
-    foreach (const SecretsRequest & request, m_calls) {
+    Q_FOREACH(const SecretsRequest & request, m_calls) {
         if (request == callId) {
             qCWarning(PLASMA_NM) << "GetSecrets was called again! This should not happen, cancelling first call" << connection_path.path() << setting_name;
             CancelGetSecrets(connection_path, setting_name);
@@ -161,7 +161,16 @@ void SecretAgent::dialogAccepted()
     for (int i = 0; i < m_calls.size(); ++i) {
         SecretsRequest request = m_calls[i];
         if (request.type == SecretsRequest::GetSecrets && request.dialog == m_dialog) {
+            NMStringMap tmpOpenconnectSecrets;
             NMVariantMapMap connection = request.dialog->secrets();
+            if (connection.contains(QLatin1String("vpn"))) {
+                if (connection.value(QLatin1String("vpn")).contains(QLatin1String("tmp-secrets"))) {
+                    QVariantMap vpnSetting = connection.value(QLatin1String("vpn"));
+                    tmpOpenconnectSecrets = qdbus_cast<NMStringMap>(vpnSetting.take(QLatin1String("tmp-secrets")));
+                    connection.insert(QLatin1String("vpn"), vpnSetting);
+                }
+            }
+
             sendSecrets(connection, request.message);
             NetworkManager::ConnectionSettings::Ptr connectionSettings = NetworkManager::ConnectionSettings::Ptr(new NetworkManager::ConnectionSettings(connection));
             NetworkManager::ConnectionSettings::Ptr completeConnectionSettings;
@@ -185,19 +194,16 @@ void SecretAgent::dialogAccepted()
                         }
                     }
                 } else if (completeConnectionSettings->connectionType() == NetworkManager::ConnectionSettings::Wireless) {
-                    NetworkManager::WirelessSetting::Ptr wirelessSetting = completeConnectionSettings->setting(NetworkManager::Setting::Wireless).staticCast<NetworkManager::WirelessSetting>();
-                    if (wirelessSetting && !wirelessSetting->security().isEmpty()) {
-                        NetworkManager::WirelessSecuritySetting::Ptr wirelessSecuritySetting = completeConnectionSettings->setting(NetworkManager::Setting::WirelessSecurity).staticCast<NetworkManager::WirelessSecuritySetting>();
-                        if (wirelessSecuritySetting && wirelessSecuritySetting->keyMgmt() == NetworkManager::WirelessSecuritySetting::WpaEap) {
-                            NetworkManager::Security8021xSetting::Ptr security8021xSetting = completeConnectionSettings->setting(NetworkManager::Setting::Security8021x).staticCast<NetworkManager::Security8021xSetting>();
-                            if (security8021xSetting) {
-                                if (security8021xSetting->eapMethods().contains(NetworkManager::Security8021xSetting::EapMethodFast) ||
-                                    security8021xSetting->eapMethods().contains(NetworkManager::Security8021xSetting::EapMethodTtls) ||
-                                    security8021xSetting->eapMethods().contains(NetworkManager::Security8021xSetting::EapMethodPeap)) {
-                                    if (security8021xSetting->passwordFlags().testFlag(NetworkManager::Setting::NotSaved) ||
-                                        security8021xSetting->passwordFlags().testFlag(NetworkManager::Setting::NotRequired)) {
-                                        requestOffline = false;
-                                    }
+                    NetworkManager::WirelessSecuritySetting::Ptr wirelessSecuritySetting = completeConnectionSettings->setting(NetworkManager::Setting::WirelessSecurity).staticCast<NetworkManager::WirelessSecuritySetting>();
+                    if (wirelessSecuritySetting && wirelessSecuritySetting->keyMgmt() == NetworkManager::WirelessSecuritySetting::WpaEap) {
+                        NetworkManager::Security8021xSetting::Ptr security8021xSetting = completeConnectionSettings->setting(NetworkManager::Setting::Security8021x).staticCast<NetworkManager::Security8021xSetting>();
+                        if (security8021xSetting) {
+                            if (security8021xSetting->eapMethods().contains(NetworkManager::Security8021xSetting::EapMethodFast) ||
+                                security8021xSetting->eapMethods().contains(NetworkManager::Security8021xSetting::EapMethodTtls) ||
+                                security8021xSetting->eapMethods().contains(NetworkManager::Security8021xSetting::EapMethodPeap)) {
+                                if (security8021xSetting->passwordFlags().testFlag(NetworkManager::Setting::NotSaved) ||
+                                    security8021xSetting->passwordFlags().testFlag(NetworkManager::Setting::NotRequired)) {
+                                    requestOffline = false;
                                 }
                             }
                         }
@@ -211,6 +217,37 @@ void SecretAgent::dialogAccepted()
                     requestOffline.saveSecretsWithoutReply = true;
                     m_calls << requestOffline;
                 }
+            } else if (request.saveSecretsWithoutReply && completeConnectionSettings->connectionType() == NetworkManager::ConnectionSettings::Vpn && !tmpOpenconnectSecrets.isEmpty()) {
+                NetworkManager::VpnSetting::Ptr vpnSetting = completeConnectionSettings->setting(NetworkManager::Setting::Vpn).staticCast<NetworkManager::VpnSetting>();
+                if (vpnSetting) {
+                    NMStringMap data = vpnSetting->data();
+                    NMStringMap secrets = vpnSetting->secrets();
+
+                    // Load secrets from auth dialog which are returned back to NM
+                    if (connection.value(QLatin1String("vpn")).contains(QLatin1String("secrets"))) {
+                        secrets.unite(qdbus_cast<NMStringMap>(connection.value(QLatin1String("vpn")).value(QLatin1String("secrets"))));
+                    }
+
+                    // Load temporary secrets from auth dialog which are not returned to NM
+                    Q_FOREACH(const QString &key, tmpOpenconnectSecrets.keys()) {
+                        if (secrets.contains(QLatin1Literal("save_passwords")) && secrets.value(QLatin1Literal("save_passwords")) == QLatin1String("yes")) {
+                            data.insert(key + QLatin1String("-flags"), QString::number(NetworkManager::Setting::AgentOwned));
+                        } else {
+                            data.insert(key + QLatin1String("-flags"), QString::number(NetworkManager::Setting::NotSaved));
+                        }
+                        secrets.insert(key, tmpOpenconnectSecrets.value(key));
+                    }
+
+                    vpnSetting->setData(data);
+                    vpnSetting->setSecrets(secrets);
+                    if (!con) {
+                        con = NetworkManager::findConnection(request.connection_path.path());
+                    }
+
+                    if (con) {
+                        con->update(completeConnectionSettings->toMap());
+                    }
+                }
             }
 
             m_calls.removeAt(i);
@@ -336,7 +373,19 @@ bool SecretAgent::processGetSecrets(SecretsRequest &request) const
     }
 
     if (!secretsMap.isEmpty()) {
-        setting->secretsFromStringMap(secretsMap);
+        // FIXME workaround just for Plasma 5.2 for a missing fix in networkmanager-qt
+        if (isVpn) {
+            NetworkManager::VpnSetting::Ptr vpnSetting = setting.staticCast<NetworkManager::VpnSetting>();
+            if (vpnSetting) {
+                NMStringMap secrets = vpnSetting->secrets();
+                vpnSetting->secretsFromStringMap(secretsMap);
+                secrets.unite(vpnSetting->secrets());
+                vpnSetting->setSecrets(secrets);
+            }
+        } else {
+            setting->secretsFromStringMap(secretsMap);
+        }
+
         if (!isVpn && setting->needSecrets(requestNew).isEmpty()) {
             // Enough secrets were retrieved from storage
             request.connection[request.setting_name] = setting->secretsToMap();
@@ -411,7 +460,7 @@ bool SecretAgent::processSaveSecrets(SecretsRequest &request) const
             }
 
             if (m_wallet->setFolder("Network Management")) {
-                foreach (const NetworkManager::Setting::Ptr &setting, connectionSettings.settings()) {
+                Q_FOREACH(const NetworkManager::Setting::Ptr &setting, connectionSettings.settings()) {
                     NMStringMap secretsMap = setting->secretsToStringMap();
 
                     if (!secretsMap.isEmpty()) {
@@ -447,9 +496,9 @@ bool SecretAgent::processDeleteSecrets(SecretsRequest &request) const
         if (m_wallet->isOpen()) {
             if (m_wallet->hasFolder("Network Management") && m_wallet->setFolder("Network Management")) {
                 NetworkManager::ConnectionSettings connectionSettings(request.connection);
-                foreach (const NetworkManager::Setting::Ptr &setting, connectionSettings.settings()) {
+                Q_FOREACH(const NetworkManager::Setting::Ptr &setting, connectionSettings.settings()) {
                     QString entryName = QLatin1Char('{') % connectionSettings.uuid() % QLatin1Char('}') % QLatin1Char(';') % setting->name();
-                    foreach (const QString &entry, m_wallet->entryList()) {
+                    Q_FOREACH(const QString &entry, m_wallet->entryList()) {
                         if (entry.startsWith(entryName)) {
                             m_wallet->removeEntry(entryName);
                         }
@@ -503,7 +552,7 @@ bool SecretAgent::useWallet() const
 bool SecretAgent::hasSecrets(const NMVariantMapMap &connection) const
 {
     NetworkManager::ConnectionSettings connectionSettings(connection);
-    foreach (const NetworkManager::Setting::Ptr &setting, connectionSettings.settings()) {
+    Q_FOREACH(const NetworkManager::Setting::Ptr &setting, connectionSettings.settings()) {
         if (!setting->secretsToMap().isEmpty()) {
             return true;
         }
@@ -527,7 +576,7 @@ void SecretAgent::importSecretsFromPlainTextFiles()
 
     // No action is required when the list of secrets is empty
     if (!config.groupList().isEmpty()) {
-        foreach (const QString &groupName, config.groupList()) {
+        Q_FOREACH(const QString &groupName, config.groupList()) {
             QString loadedUuid = groupName.split(';').first().remove('{').remove('}');
             QString loadedSettingType = groupName.split(';').last();
             NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(loadedUuid);
@@ -536,7 +585,7 @@ void SecretAgent::importSecretsFromPlainTextFiles()
                 QMap<QString, QString> secrets = config.entryMap(groupName);
                 NMVariantMapMap settings = connection->settings()->toMap();
 
-                foreach (const QString &setting, settings.keys()) {
+                Q_FOREACH(const QString &setting, settings.keys()) {
                     if (setting == QLatin1String("vpn")) {
                         NetworkManager::VpnSetting::Ptr vpnSetting = connection->settings()->setting(NetworkManager::Setting::Vpn).staticCast<NetworkManager::VpnSetting>();
                         if (vpnSetting) {
@@ -546,7 +595,7 @@ void SecretAgent::importSecretsFromPlainTextFiles()
                             NMStringMap vpnData = vpnSetting->data();
                             // Reset flags, we can't save secrets to our secret agent when KWallet is not enabled, because
                             // we dropped support for plaintext files, therefore they need to be stored to NetworkManager
-                            foreach (const QString &key, vpnData.keys()) {
+                            Q_FOREACH(const QString &key, vpnData.keys()) {
                                 if (key.endsWith(QLatin1String("-flags"))) {
                                     vpnData.insert(key, QString::number((int)secretFlags));
                                 }
@@ -561,7 +610,7 @@ void SecretAgent::importSecretsFromPlainTextFiles()
                             QVariantMap tmpSetting = settings.value(setting);
                             // Reset flags, we can't save secrets to our secret agent when KWallet is not enabled, because
                             // we dropped support for plaintext files, therefore they need to be stored to NetworkManager
-                            foreach (const QString &key, tmpSetting.keys()) {
+                            Q_FOREACH(const QString &key, tmpSetting.keys()) {
                                 if (key.endsWith(QLatin1String("-flags"))) {
                                     tmpSetting.insert(key, (int)secretFlags);
                                 }
