@@ -214,7 +214,7 @@ void BridgeWidget::populateBridges()
 {
     m_ui->bridges->clear();
 
-    foreach (const NetworkManager::Connection::Ptr &connection, NetworkManager::listConnections()) {
+    Q_FOREACH(const NetworkManager::Connection::Ptr &connection, NetworkManager::listConnections()) {
         NetworkManager::ConnectionSettings::Ptr settings = connection->settings();
         if (settings->master() == m_uuid && settings->slaveType() == type()) {
             const QString label = QString("%1 (%2)").arg(connection->name()).arg(connection->settings()->typeAsString(connection->settings()->connectionType()));
