@@ -111,7 +111,7 @@ bool IpV6RoutesWidget::ignoreautoroutes() const
 void IpV6RoutesWidget::setRoutes(const QList<NetworkManager::IpRoute> &list)
 {
     d->model.removeRows(0, d->model.rowCount());
-    foreach (const NetworkManager::IpRoute &route, list) {
+    Q_FOREACH(const NetworkManager::IpRoute &route, list) {
         QList<QStandardItem *> item;
         // qCDebug(PLASMA_NM) << route.ip();
         item << new QStandardItem(route.ip().toString())
