@@ -24,6 +24,8 @@
 #include "networkmodelitem.h"
 #include "uiutils.h"
 
+#include <NetworkManagerQt/Settings>
+
 #include <QIcon>
 #include <QFont>
 
@@ -50,7 +52,7 @@ int EditorIdentityModel::columnCount(const QModelIndex& parent) const
 {
     Q_UNUSED(parent);
 
-    return 2;
+    return 3;
 }
 
 QVariant EditorIdentityModel::headerData(int section, Qt::Orientation orientation, int role) const
@@ -60,6 +62,8 @@ QVariant EditorIdentityModel::headerData(int section, Qt::Orientation orientatio
         case 0:
             return i18n("Connection name");
         case 1:
+            return i18n("Connection type");
+        case 2:
             return i18n("Last used");
         }
     }
@@ -75,8 +79,18 @@ QVariant EditorIdentityModel::data(const QModelIndex& index, int role) const
     const bool isActivated = (NetworkManager::ActiveConnection::State) sourceModel()->data(sourceIndex, NetworkModel::ConnectionStateRole).toInt()
                              == NetworkManager::ActiveConnection::Activated;
     NetworkManager::ConnectionSettings::ConnectionType type = static_cast<NetworkManager::ConnectionSettings::ConnectionType>(sourceModel()->data(sourceIndex, NetworkModel::TypeRole).toInt());
+
+    NetworkManager::ConnectionSettings::Ptr settings;
+    NetworkManager::VpnSetting::Ptr vpnSetting ;
+    if (type == NetworkManager::ConnectionSettings::Vpn) {
+        settings = NetworkManager::findConnection(sourceModel()->data(sourceIndex, NetworkModel::ConnectionPathRole).toString())->settings();
+        if (settings) {
+            vpnSetting = settings->setting(NetworkManager::Setting::Vpn).staticCast<NetworkManager::VpnSetting>();
+        }
+    }
+
     QString tooltip;
-    QString iconName = UiUtils::iconAndTitleForConnectionSettingsType(type, tooltip);
+    const QString iconName = UiUtils::iconAndTitleForConnectionSettingsType(type, tooltip);
     const int column = index.column();
 
     if (role == Qt::DisplayRole) {
@@ -93,6 +107,11 @@ QVariant EditorIdentityModel::data(const QModelIndex& index, int role) const
             }
             return connectionName;
         case 1:
+            if (type == NetworkManager::ConnectionSettings::Vpn && vpnSetting) {
+                return QString("%1 (%2)").arg(tooltip).arg(vpnSetting->serviceType().section('.', -1));
+            }
+            return tooltip;
+        case 2:
             return lastUsed;
         }
     } else if (role == Qt::DecorationRole) {
